@@ -9,8 +9,6 @@ It provides
 * Frontend (Plone-Volto, a ReactJS based user interface)
 * Varnish using kube-httpcache. It includes a way to invalidate varnish cluster (optional)
 
-## Installation
-
 ### Typescript
 
 To use this library, create a new CDK8S project (or use an existing one)
@@ -72,7 +70,12 @@ For more have a look at the [example project](https://github.com/bluedynamics/cd
 Clone the repository and install the dependencies:
 
 ```bash
-yarn install
+```
+
+nvm use lts/*
+npm install yarn
+projen
+
 ```
 
 Then run the following command to run the test:
@@ -130,7 +133,22 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
+import typeguard
+from importlib.metadata import version as _metadata_package_version
+TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])
+
+def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
+    if TYPEGUARD_MAJOR_VERSION <= 2:
+        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
+    else:
+        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
+           pass
+        else:
+            if TYPEGUARD_MAJOR_VERSION == 3:
+                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
+                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
+            else:
+                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore
 
 from ._jsii import *
 
@@ -210,6 +228,7 @@ class Plone(
         "image_pull_policy": "imagePullPolicy",
         "limit_cpu": "limitCpu",
         "limit_memory": "limitMemory",
+        "liveness_enabled": "livenessEnabled",
         "liveness_failure_threshold": "livenessFailureThreshold",
         "liveness_iimeout_seconds": "livenessIimeoutSeconds",
         "liveness_initial_delay_seconds": "livenessInitialDelaySeconds",
@@ -217,6 +236,7 @@ class Plone(
         "liveness_success_threshold": "livenessSuccessThreshold",
         "max_unavailable": "maxUnavailable",
         "min_available": "minAvailable",
+        "readiness_enabled": "readinessEnabled",
         "readiness_failure_threshold": "readinessFailureThreshold",
         "readiness_iimeout_seconds": "readinessIimeoutSeconds",
         "readiness_initial_delay_seconds": "readinessInitialDelaySeconds",
@@ -236,6 +256,7 @@ class PloneBaseOptions:
         image_pull_policy: typing.Optional[builtins.str] = None,
         limit_cpu: typing.Optional[builtins.str] = None,
         limit_memory: typing.Optional[builtins.str] = None,
+        liveness_enabled: typing.Optional[builtins.bool] = None,
         liveness_failure_threshold: typing.Optional[jsii.Number] = None,
         liveness_iimeout_seconds: typing.Optional[jsii.Number] = None,
         liveness_initial_delay_seconds: typing.Optional[jsii.Number] = None,
@@ -243,6 +264,7 @@ class PloneBaseOptions:
         liveness_success_threshold: typing.Optional[jsii.Number] = None,
         max_unavailable: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
         min_available: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
+        readiness_enabled: typing.Optional[builtins.bool] = None,
         readiness_failure_threshold: typing.Optional[jsii.Number] = None,
         readiness_iimeout_seconds: typing.Optional[jsii.Number] = None,
         readiness_initial_delay_seconds: typing.Optional[jsii.Number] = None,
@@ -258,6 +280,7 @@ class PloneBaseOptions:
         :param image_pull_policy: 
         :param limit_cpu: 
         :param limit_memory: 
+        :param liveness_enabled: 
         :param liveness_failure_threshold: 
         :param liveness_iimeout_seconds: 
         :param liveness_initial_delay_seconds: 
@@ -265,6 +288,7 @@ class PloneBaseOptions:
         :param liveness_success_threshold: 
         :param max_unavailable: 
         :param min_available: 
+        :param readiness_enabled: 
         :param readiness_failure_threshold: 
         :param readiness_iimeout_seconds: 
         :param readiness_initial_delay_seconds: 
@@ -281,6 +305,7 @@ class PloneBaseOptions:
             check_type(argname="argument image_pull_policy", value=image_pull_policy, expected_type=type_hints["image_pull_policy"])
             check_type(argname="argument limit_cpu", value=limit_cpu, expected_type=type_hints["limit_cpu"])
             check_type(argname="argument limit_memory", value=limit_memory, expected_type=type_hints["limit_memory"])
+            check_type(argname="argument liveness_enabled", value=liveness_enabled, expected_type=type_hints["liveness_enabled"])
             check_type(argname="argument liveness_failure_threshold", value=liveness_failure_threshold, expected_type=type_hints["liveness_failure_threshold"])
             check_type(argname="argument liveness_iimeout_seconds", value=liveness_iimeout_seconds, expected_type=type_hints["liveness_iimeout_seconds"])
             check_type(argname="argument liveness_initial_delay_seconds", value=liveness_initial_delay_seconds, expected_type=type_hints["liveness_initial_delay_seconds"])
@@ -288,6 +313,7 @@ class PloneBaseOptions:
             check_type(argname="argument liveness_success_threshold", value=liveness_success_threshold, expected_type=type_hints["liveness_success_threshold"])
             check_type(argname="argument max_unavailable", value=max_unavailable, expected_type=type_hints["max_unavailable"])
             check_type(argname="argument min_available", value=min_available, expected_type=type_hints["min_available"])
+            check_type(argname="argument readiness_enabled", value=readiness_enabled, expected_type=type_hints["readiness_enabled"])
             check_type(argname="argument readiness_failure_threshold", value=readiness_failure_threshold, expected_type=type_hints["readiness_failure_threshold"])
             check_type(argname="argument readiness_iimeout_seconds", value=readiness_iimeout_seconds, expected_type=type_hints["readiness_iimeout_seconds"])
             check_type(argname="argument readiness_initial_delay_seconds", value=readiness_initial_delay_seconds, expected_type=type_hints["readiness_initial_delay_seconds"])
@@ -307,6 +333,8 @@ class PloneBaseOptions:
             self._values["limit_cpu"] = limit_cpu
         if limit_memory is not None:
             self._values["limit_memory"] = limit_memory
+        if liveness_enabled is not None:
+            self._values["liveness_enabled"] = liveness_enabled
         if liveness_failure_threshold is not None:
             self._values["liveness_failure_threshold"] = liveness_failure_threshold
         if liveness_iimeout_seconds is not None:
@@ -321,6 +349,8 @@ class PloneBaseOptions:
             self._values["max_unavailable"] = max_unavailable
         if min_available is not None:
             self._values["min_available"] = min_available
+        if readiness_enabled is not None:
+            self._values["readiness_enabled"] = readiness_enabled
         if readiness_failure_threshold is not None:
             self._values["readiness_failure_threshold"] = readiness_failure_threshold
         if readiness_iimeout_seconds is not None:
@@ -363,6 +393,11 @@ class PloneBaseOptions:
         result = self._values.get("limit_memory")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def liveness_enabled(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("liveness_enabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def liveness_failure_threshold(self) -> typing.Optional[jsii.Number]:
         result = self._values.get("liveness_failure_threshold")
@@ -400,6 +435,11 @@ class PloneBaseOptions:
         result = self._values.get("min_available")
         return typing.cast(typing.Optional[typing.Union[builtins.str, jsii.Number]], result)
 
+    @builtins.property
+    def readiness_enabled(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("readiness_enabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def readiness_failure_threshold(self) -> typing.Optional[jsii.Number]:
         result = self._values.get("readiness_failure_threshold")
@@ -777,6 +817,7 @@ def _typecheckingstub__cd9cf17a63ac3f69f433db3caa859d98a750929386f09ada26dd0fd21
     image_pull_policy: typing.Optional[builtins.str] = None,
     limit_cpu: typing.Optional[builtins.str] = None,
     limit_memory: typing.Optional[builtins.str] = None,
+    liveness_enabled: typing.Optional[builtins.bool] = None,
     liveness_failure_threshold: typing.Optional[jsii.Number] = None,
     liveness_iimeout_seconds: typing.Optional[jsii.Number] = None,
     liveness_initial_delay_seconds: typing.Optional[jsii.Number] = None,
@@ -784,6 +825,7 @@ def _typecheckingstub__cd9cf17a63ac3f69f433db3caa859d98a750929386f09ada26dd0fd21
     liveness_success_threshold: typing.Optional[jsii.Number] = None,
     max_unavailable: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
     min_available: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
+    readiness_enabled: typing.Optional[builtins.bool] = None,
     readiness_failure_threshold: typing.Optional[jsii.Number] = None,
     readiness_iimeout_seconds: typing.Optional[jsii.Number] = None,
     readiness_initial_delay_seconds: typing.Optional[jsii.Number] = None,
